@@ -9,7 +9,7 @@ class AnalysisObject(object):
                  mc_name:Optional[str]=None, snapshot_name:Optional[str]=None,
                  minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', precision:float=0.001, 
                  eps:float=1.0, strategy:int=0, print_level:int=1, timer:bool=True,
-                 num_cpu:int=1, offset:bool=True, optimize:bool=True, eigen:bool=False,
+                 num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False,
                  fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                  max_iters:int=-1, constrain_nuis:bool=True, **kwargs):
         
