@@ -228,5 +228,5 @@ class NuisanceParameterHarmonizer(object):
         harmonize_map = self._harmonize_multi_input(input_paths)
         if outfile is not None:
             json.dump(harmonize_map, open(outfile, 'w'), indent=2)
-            timely_info('Saved rename output as ', ','.join(outfile))
+            timely_info('Saved rename output as ', outfile)
         return harmonize_map
